<?php

namespace Elementor;

if (!defined('ABSPATH')) exit;

class herowp_Widget_Product_Addtocart_Btn extends Widget_Base
{

    public function get_name()
    {
        return 'product_addtocart_btn';
    }

    public function get_title()
    {
        return esc_html__('دکمه افزودن به سبد', 'emperor');
    }

    public function get_icon()
    {
        return 'eicon-product-images';
    }

    public function get_categories()
    {
        return ['emperor-product-elements'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'product_addtocart_btn_section',
            [
                'label' => esc_html__('دکمه افزودن به سبد', 'emperor'),
                'type' => Controls_Manager::SECTION,
            ]
        );


        $this->add_control(
            'btn-padding',
            [
                'label' => __( 'پدینگ', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '20px', 'elementor' ),
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'padding: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-size',
            [
                'label' => __( 'سایز متن', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '14px', 'elementor' ),
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'font-size: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-weight',
            [
                'label' => __( 'ضخامت متن', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( '400', 'elementor' ),
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'font-weight: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-color',
            [
                'label' => __( 'رنگ متن', 'emperor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'color: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-bg',
            [
                'label' => __( 'پس زمینه', 'emperor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#1fbd50',
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'background: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-shadow',
            [
                'label' => __( 'سایه', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'default' => __( '0 0 13px 1px rgb(70 72 77 / 8%)', 'elementor' ),
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'box-shadow: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'btn-border',
            [
                'label' => __( 'گوشه های گرد', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '8', 'elementor' ),
                'selectors' => [
                    '{{WRAPPER}} .product-addtocart-btn-el .single_add_to_cart_button' => 'border-radius: {{VALUE}}px !important;',
                ],
            ]
        );

        $this->add_control(
            'btn-title',
            [
                'label' => __( 'عنوان دکمه', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'عنوان دکمه', 'elementor' ),
                'default' => __( 'افزودن به سبد', 'elementor' ),
            ]
        );


        $this->end_controls_section();
    }

    protected function render($instance = [])
    {
        global $product;


        $settings = $this->get_settings_for_display();
        ?>

        <div class="product-addtocart-btn-el">
            <form class="cart" method="post" enctype='multipart/form-data'>
                <?php

                woocommerce_quantity_input( array(
                    'min_value'   => apply_filters( 'woocommerce_quantity_input_min', 1, $product ),
                    'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
                    'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( $_POST['quantity'] ) : $product->get_min_purchase_quantity(),
                ) );

                ?>

                <button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="single_add_to_cart_button button alt"><?php echo $settings['btn-title']; ?></button>

            </form>
        </div>

        <?php
    }
}

Plugin::instance()->widgets_manager->register_widget_type(new herowp_Widget_Product_Addtocart_Btn());