<?php

namespace Elementor;

if (!defined('ABSPATH')) exit;

class herowp_Widget_Product_Bread extends Widget_Base
{

    public function get_name()
    {
        return 'product_bread';
    }

    public function get_title()
    {
        return esc_html__('مسیر محصول', 'emperor');
    }

    public function get_icon()
    {
        return 'eicon-product-images';
    }

    public function get_categories()
    {
        return ['emperor-product-elements'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'product_bread_section',
            [
                'label' => esc_html__('مسیر محصول', 'emperor'),
                'type' => Controls_Manager::SECTION,
            ]
        );

        $this->add_control(
             'show-icon',
            [
                'label' => __('نمایش آیکون', 'elementor'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __('بله', 'elementor'),
                'label_off' => __('خیر', 'elementor'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'icon-border',
            [
                'label' => __( 'گوشه های گرد آیکون (px)', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '10', 'elementor' ),
                'condition' => [
                    'show-icon' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .fal' => 'border-radius: {{VALUE}}px !important;',
                ],
            ]
        );

        $this->add_control(
            'icon-size',
            [
                'label' => __( 'سایز آیکون (px)', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '20', 'elementor' ),
                'condition' => [
                    'show-icon' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .fal' => 'font-size: {{VALUE}}px !important;',
                ],
            ]
        );

        $this->add_control(
            'icon-padding',
            [
                'label' => __( 'پدینگ آیکون (px)', 'elementor' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'به پیکسل', 'elementor' ),
                'default' => __( '10px 8px', 'elementor' ),
                'condition' => [
                    'show-icon' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .fal' => 'padding: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'icon-bg',
            [
                'label' => __( 'پس زمینه آیکون', 'emperor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#f0f2f7',
                'condition' => [
                    'show-icon' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .fal' => 'background: {{VALUE}} !important;',
                ],
            ]
        );
        $this->add_control(
            'icon-color',
            [
                'label' => __( 'رنگ آیکون', 'emperor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#909aa7',
                'condition' => [
                    'show-icon' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .fal' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'a-color',
            [
                'label' => __( 'رنگ لینک', 'emperor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#7f8187',
                'selectors' => [
                    '{{WRAPPER}} .product-bread-el .woocommerce-breadcrumb, .product-bread-el .woocommerce-breadcrumb a, .product-bread-el .woocommerce-breadcrumb i' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render($instance = [])
    {
        $settings = $this->get_settings_for_display();

        ?>

        <div class="product-bread-el d-flex align-items-center">
            <?php if ($settings['show-icon'] === 'yes'): ?>
                <i class="fal fa-house"></i>
            <?php endif; ?>

            <div class="<?= $settings['a-color'] === 'white' ? 'bread-white' : '' ?>">
                <?php woocommerce_breadcrumb(); ?>
            </div>
        </div>

        <?php
    }
}

Plugin::instance()->widgets_manager->register_widget_type(new herowp_Widget_Product_Bread);