<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class herowp_Widget_products_icon extends Widget_Base {

   public function get_name() {
      return 'Products-icon';
   }

   public function get_title() {
      return esc_html__( 'محصولات حالت آیکون', 'emperor' );
   }

   public function get_icon() {
        return 'eicon-form-vertical';
   }

   public function get_categories() {
      return [ 'emperor-elements' ];
   }

   protected function _register_controls() {

      $this->start_controls_section(
         'products_section',
         [
            'label' => esc_html__( 'محصولات حالت آیکون', 'emperor' ),
            'type' => Controls_Manager::SECTION,
         ]
      );

      $this->add_control(
         'category',
         [
            'label' => esc_html__( 'Category', 'emperor' ),
            'type' => Controls_Manager::SELECT2,
            'title' => esc_html__( 'Select a category', 'emperor' ),
            'multiple' => true,
            'options' => herowp_get_terms_dropdown_array([
               'taxonomy' => 'product_cat',
               'hide_empty' => false,
            ]),
         ]
      );

      $this->add_control(
         'ppp',
         [
            'label' => __( 'Number of Items', 'emperor' ),
            'type' => Controls_Manager::SLIDER,
            'range' => [
               'no' => [
                  'min' => 0,
                  'max' => 100,
                  'step' => 1,
               ],
            ],
            'default' => [
               'size' => 18,
            ]
         ]
      );

      $this->add_control(
         'order',
         [
            'label' => __( 'order', 'emperor' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'default' => 'DESC',
            'options' => [
               'ASC'  => __( 'Ascending', 'emperor' ),
               'DESC' => __( 'Descending', 'emperor' )
            ],
         ]
      );

      $this->end_controls_section();

   }

   protected function render( $instance = [] ) {

      // get our input from the widget settings.

      $settings = $this->get_settings_for_display(); ?>

      <div class="elementor-products-icon">
         <?php

         $category = !empty( $settings['category'] ) ? $settings['category'] : 'All';


         $products = new \WP_Query( array(
            'post_type' => 'product',
            'posts_per_page' => $settings['ppp']['size'],
            'order' => $settings['order'],
            'tax_query'     => array(
                 array(
                     'taxonomy'  => 'product_cat',
                     'field'     => 'id',
                     'terms'     => $category,

                 )
             ),

         ));

         while ( $products->have_posts() ) : $products->the_post();
             global $product;
             $prefix = '_herowp_';
             $product_icon = get_post_meta(get_the_ID(), $prefix . 'emperor_product_icon', true);

             $vip_status = false;
             if (is_plugin_active('restrict-content-pro/restrict-content-pro.php')){
                 $vip_status = get_post_meta(get_the_ID(), $prefix . 'course_vip_access', true);
             }
                 ?>

               <div class="product-icon-item-holder" data-title="<?php the_title(); ?>" data-price="<?php echo $vip_status ? 'اعضای ویژه' : $product->get_price(); ?>" data-cover="<?php echo get_the_post_thumbnail_url( $product->id) ?>">
                   <div class="product-icon-item">
                       <a href="<?php the_permalink() ?>">
                           <img src="<?php echo esc_url($product_icon); ?>" alt="<?php the_title(); ?>">
                       </a>
                   </div>
               </div>
            
         <?php
         endwhile;
      wp_reset_postdata();
      ?>
      </div>
   <?php
   }

}

Plugin::instance()->widgets_manager->register_widget_type( new herowp_Widget_products_icon );
