<?php

class emperor_mega_menu
{
    /*--------------------------------------------*
     * Constructor
     *--------------------------------------------*/
    /**
     * Initializes the plugin by setting localization, filters, and administration functions.
     */
    public function __construct()
    {
        // add new fields via hook
        add_action('wp_nav_menu_item_custom_fields', array( $this, 'emperor_mega_menu_add_custom_fields' ), 10, 5);
        // add custom menu fields to menu
        add_filter('wp_setup_nav_menu_item', array( $this, 'emperor_mega_menu_add_custom_nav_fields' ));
        // save menu custom fields
        add_action('wp_update_nav_menu_item', array( $this, 'emperor_mega_menu_update_custom_nav_fields' ), 10, 3);
        // edit menu walker
        // add_filter( 'wp_edit_nav_menu_walker', array( $this, 'emperor_mega_menu_edit_walker' ), 10, 2 );
    } // end constructor
    /**
     * Add custom fields to edit menu page
     *
     * @access      public
     * @since       1.0
     * @return      void
     */
    public function emperor_get_megamenu()
    {
        $megamenu = array();
        $megamenus = get_posts(array('posts_per_page'=>-1,'post_type'=>'herowpmega'));
        foreach ($megamenus as $value) {
            $megamenu[$value->ID] = $value->post_title;
        }
        return $megamenu;
    }
    public function emperor_mega_menu_add_custom_fields($item_id, $item, $depth, $args)
    {
        ?>
        	<div class="menu-options">
				<?php if ($depth == 0) { ?>
					<h4><?php esc_html_e('تنظیمات مگامنو', 'emperor'); ?></h4>
					<p class="field-custom description description-wide">
						<label for="edit-menu-megamenu-<?php echo esc_attr($item_id); ?>">
							<?php esc_html_e('فعالسازی مگامنو', 'emperor'); ?>
							<input type="checkbox" id="edit-menu-megamenu-<?php echo esc_attr($item_id); ?>"
								   class="edit-menu-item-custom" id="menu-megamenu[<?php echo esc_attr($item_id); ?>]"
								   name="menu-megamenu[<?php echo esc_attr($item_id); ?>]"
								   value="1" <?php echo checked(! empty($item->megamenu), 1, false); ?> />
						</label>
					</p>
					<?php $megamenus = self::emperor_get_megamenu(); ?>
					<p class="field-custom description description-wide">
						<label for="edit-menu-submegamenu-<?php echo esc_attr($item_id); ?>">
							<?php esc_html_e('انتخاب مگامنو فرعی', 'emperor'); ?>
							<select class="fat" id="edit-menu-submegamenu-<?php echo esc_attr($item_id); ?>"
									name="menu-submegamenu[<?php echo esc_attr($item_id); ?>]">
								<?php echo '<option value = "">' . esc_html__('خیر', 'emperor') . '</option>'; ?>
								<?php foreach($megamenus as $key=>$submenu) {
								    if ($key == $item->submegamenu) {
								        echo '<option value = "'.esc_html($key).'" selected="selected">' . esc_html($submenu) . '</option>';
								    } else {
								        echo '<option value = "'.esc_html($key).'">' . esc_html($submenu) . '</option>';
								    }
								}
				    ?>
							</select>
						</label>
					</p>					
					<p class="field-custom description description-wide">
						<label for="edit-menu-is-fullwidth-<?php echo esc_attr($item_id); ?>">
							<?php esc_html_e('مگامنو تمام عرض', 'emperor'); ?>
							<input type="checkbox" id="edit-menu-is-fullwidth-<?php echo esc_attr($item_id); ?>"
								   class="edit-menu-item-custom" id="menu-is-fullwidth[<?php echo esc_attr($item_id); ?>]"
								   name="menu-is-fullwidth[<?php echo esc_attr($item_id); ?>]"
								   value="1" <?php echo checked(! empty($item->isfullwidth), 1, false); ?> />
						</label>
					</p>
				<?php } ?>
            </div>
        	<?php
    }
    /**
     * Add custom fields to $item nav object
     * in order to be used in custom Walker
     *
     * @access      public
     * @since       1.0
     * @return      void
     */
    public function emperor_mega_menu_add_custom_nav_fields($menu_item)
    {
        $menu_item->subtitle        = get_post_meta($menu_item->ID, '_menu_item_subtitle', true);
        $menu_item->megamenu        = get_post_meta($menu_item->ID, '_menu_megamenu', true);
        $menu_item->submegamenu     = get_post_meta($menu_item->ID, '_menu_submegamenu', true);
        $menu_item->isfullwidth  = get_post_meta($menu_item->ID, '_menu_is_fullwidth', true);
        $menu_item->loggedin     = get_post_meta($menu_item->ID, '_menu_loggedin', true);
        $menu_item->loggedout    = get_post_meta($menu_item->ID, '_menu_loggedout', true);
        // $menu_item->newbadge   		= get_post_meta( $menu_item->ID, '_menu_newbadge', true );
        //$menu_item->salebadge   		= get_post_meta( $menu_item->ID, '_menu_salebadge', true );
        $menu_item->icon        = get_post_meta($menu_item->ID, '_menu_item_icon', true);
        $menu_item->imagemenu       = get_post_meta($menu_item->ID, '_menu_item_imagemenu', true);
        return $menu_item;
    }
    /**
     * Save menu custom fields
     *
     * @access      public
     * @since       1.0
     * @return      void
     */
    public function emperor_mega_menu_update_custom_nav_fields($menu_id, $menu_item_db_id, $args)
    {
        // Check if element is properly sent
        if (isset($_REQUEST['menu-item-subtitle'])) {
            $subtitle_value = $_REQUEST['menu-item-subtitle'][ $menu_item_db_id ];
            update_post_meta($menu_item_db_id, '_menu_item_subtitle', $subtitle_value);
        }
        if (isset($_REQUEST['menu-item-icon'][ $menu_item_db_id ])) {
            $menu_icon_value = $_REQUEST['menu-item-icon'][ $menu_item_db_id ];
            update_post_meta($menu_item_db_id, '_menu_item_icon', $menu_icon_value);
        }
        if (isset($_REQUEST['menu-item-imagemenu'][ $menu_item_db_id ])) {
            $menu_imagemenu_value = $_REQUEST['menu-item-imagemenu'][ $menu_item_db_id ];
            update_post_meta($menu_item_db_id, '_menu_item_imagemenu', $menu_imagemenu_value);
        }
        if (isset($_REQUEST['menu-megamenu'][ $menu_item_db_id ])) {
            update_post_meta($menu_item_db_id, '_menu_megamenu', 1);
        } else {
            update_post_meta($menu_item_db_id, '_menu_megamenu', 0);
        }
        if (isset($_REQUEST['menu-submegamenu'][ $menu_item_db_id ])) {
            $menu_submegamenu_value = $_REQUEST['menu-submegamenu'][ $menu_item_db_id ];
            update_post_meta($menu_item_db_id, '_menu_submegamenu', $menu_submegamenu_value);
        }
        if (isset($_REQUEST['menu-is-fullwidth'][ $menu_item_db_id ])) {
            update_post_meta($menu_item_db_id, '_menu_is_fullwidth', 1);
        } else {
            update_post_meta($menu_item_db_id, '_menu_is_fullwidth', 0);
        }
        if (isset($_REQUEST['menu-loggedin'][ $menu_item_db_id ])) {
            update_post_meta($menu_item_db_id, '_menu_loggedin', 1);
        } else {
            update_post_meta($menu_item_db_id, '_menu_loggedin', 0);
        }
        if (isset($_REQUEST['menu-loggedout'][ $menu_item_db_id ])) {
            update_post_meta($menu_item_db_id, '_menu_loggedout', 1);
        } else {
            update_post_meta($menu_item_db_id, '_menu_loggedout', 0);
        }
        /*    if ( isset( $_REQUEST['menu-newbadge'][ $menu_item_db_id ] ) ) {
                update_post_meta( $menu_item_db_id, '_menu_newbadge', 1 );
            } else {
                update_post_meta( $menu_item_db_id, '_menu_newbadge', 0 );
            }
            if ( isset( $_REQUEST['menu-salebadge'][ $menu_item_db_id ] ) ) {
                update_post_meta( $menu_item_db_id, '_menu_salebadge', 1 );
            } else {
                update_post_meta( $menu_item_db_id, '_menu_salebadge', 0 );
            }*/
    }
    /**
     * Define new Walker edit
     *
     * @access      public
     * @since       1.0
     * @return      void
     */
    public function emperor_mega_menu_edit_walker($walker, $menu_id)
    {
        // return 'Walker_Nav_Menu_Edit_Custom';
    }
}
$GLOBALS['emperor_mega_menu'] = new emperor_mega_menu();
?>